.. _utilipy-imports-extended:

*****************************************************
Extended Imports (`utilipy.imports.extended_imports`)
*****************************************************

.. currentmodule:: utilipy.imports.extended_imports


Reference/API
=============

.. automodapi:: utilipy.imports.extended_imports
